Documentation
¶
Index ¶
- Constants
- func RegisterSchema(reg *schemas.Registry)
- type LexedStatements
- func (LexedStatements) DecodeFromPtr(p capnp.Ptr) LexedStatements
- func (s LexedStatements) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr
- func (s LexedStatements) HasStatements() bool
- func (s LexedStatements) IsValid() bool
- func (s LexedStatements) Message() *capnp.Message
- func (s LexedStatements) NewStatements(n int32) (Statement_List, error)
- func (s LexedStatements) Segment() *capnp.Segment
- func (s LexedStatements) SetStatements(v Statement_List) error
- func (s LexedStatements) Statements() (Statement_List, error)
- func (s LexedStatements) String() string
- func (s LexedStatements) ToPtr() capnp.Ptr
- type LexedStatements_Future
- type LexedStatements_List
- type LexedTokens
- func (LexedTokens) DecodeFromPtr(p capnp.Ptr) LexedTokens
- func (s LexedTokens) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr
- func (s LexedTokens) HasTokens() bool
- func (s LexedTokens) IsValid() bool
- func (s LexedTokens) Message() *capnp.Message
- func (s LexedTokens) NewTokens(n int32) (Token_List, error)
- func (s LexedTokens) Segment() *capnp.Segment
- func (s LexedTokens) SetTokens(v Token_List) error
- func (s LexedTokens) String() string
- func (s LexedTokens) ToPtr() capnp.Ptr
- func (s LexedTokens) Tokens() (Token_List, error)
- type LexedTokens_Future
- type LexedTokens_List
- type Statement
- func (s Statement) Block() (Statement_List, error)
- func (Statement) DecodeFromPtr(p capnp.Ptr) Statement
- func (s Statement) DocComment() (string, error)
- func (s Statement) DocCommentBytes() ([]byte, error)
- func (s Statement) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr
- func (s Statement) EndByte() uint32
- func (s Statement) HasBlock() bool
- func (s Statement) HasDocComment() bool
- func (s Statement) HasTokens() bool
- func (s Statement) IsValid() bool
- func (s Statement) Message() *capnp.Message
- func (s Statement) NewBlock(n int32) (Statement_List, error)
- func (s Statement) NewTokens(n int32) (Token_List, error)
- func (s Statement) Segment() *capnp.Segment
- func (s Statement) SetBlock(v Statement_List) error
- func (s Statement) SetDocComment(v string) error
- func (s Statement) SetEndByte(v uint32)
- func (s Statement) SetLine()
- func (s Statement) SetStartByte(v uint32)
- func (s Statement) SetTokens(v Token_List) error
- func (s Statement) StartByte() uint32
- func (s Statement) String() string
- func (s Statement) ToPtr() capnp.Ptr
- func (s Statement) Tokens() (Token_List, error)
- func (s Statement) Which() Statement_Which
- type Statement_Future
- type Statement_List
- type Statement_Which
- type Token
- func (s Token) BinaryLiteral() ([]byte, error)
- func (s Token) BracketedList() (capnp.PointerList, error)
- func (Token) DecodeFromPtr(p capnp.Ptr) Token
- func (s Token) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr
- func (s Token) EndByte() uint32
- func (s Token) FloatLiteral() float64
- func (s Token) HasBinaryLiteral() bool
- func (s Token) HasBracketedList() bool
- func (s Token) HasIdentifier() bool
- func (s Token) HasOperator() bool
- func (s Token) HasParenthesizedList() bool
- func (s Token) HasStringLiteral() bool
- func (s Token) Identifier() (string, error)
- func (s Token) IdentifierBytes() ([]byte, error)
- func (s Token) IntegerLiteral() uint64
- func (s Token) IsValid() bool
- func (s Token) Message() *capnp.Message
- func (s Token) NewBracketedList(n int32) (capnp.PointerList, error)
- func (s Token) NewParenthesizedList(n int32) (capnp.PointerList, error)
- func (s Token) Operator() (string, error)
- func (s Token) OperatorBytes() ([]byte, error)
- func (s Token) ParenthesizedList() (capnp.PointerList, error)
- func (s Token) Segment() *capnp.Segment
- func (s Token) SetBinaryLiteral(v []byte) error
- func (s Token) SetBracketedList(v capnp.PointerList) error
- func (s Token) SetEndByte(v uint32)
- func (s Token) SetFloatLiteral(v float64)
- func (s Token) SetIdentifier(v string) error
- func (s Token) SetIntegerLiteral(v uint64)
- func (s Token) SetOperator(v string) error
- func (s Token) SetParenthesizedList(v capnp.PointerList) error
- func (s Token) SetStartByte(v uint32)
- func (s Token) SetStringLiteral(v string) error
- func (s Token) StartByte() uint32
- func (s Token) String() string
- func (s Token) StringLiteral() (string, error)
- func (s Token) StringLiteralBytes() ([]byte, error)
- func (s Token) ToPtr() capnp.Ptr
- func (s Token) Which() Token_Which
- type Token_Future
- type Token_List
- type Token_Which
Constants ¶
const LexedStatements_TypeID = 0xa11f97b9d6c73dd4
LexedStatements_TypeID is the unique identifier for the type LexedStatements.
const LexedTokens_TypeID = 0x9e69a92512b19d18
LexedTokens_TypeID is the unique identifier for the type LexedTokens.
const Statement_TypeID = 0xc6725e678d60fa37
Statement_TypeID is the unique identifier for the type Statement.
const Token_TypeID = 0x91cc55cd57de5419
Token_TypeID is the unique identifier for the type Token.
Variables ¶
This section is empty.
Functions ¶
func RegisterSchema ¶
Types ¶
type LexedStatements ¶
func NewLexedStatements ¶
func NewLexedStatements(s *capnp.Segment) (LexedStatements, error)
func NewRootLexedStatements ¶
func NewRootLexedStatements(s *capnp.Segment) (LexedStatements, error)
func ReadRootLexedStatements ¶
func ReadRootLexedStatements(msg *capnp.Message) (LexedStatements, error)
func (LexedStatements) DecodeFromPtr ¶
func (LexedStatements) DecodeFromPtr(p capnp.Ptr) LexedStatements
func (LexedStatements) EncodeAsPtr ¶
func (s LexedStatements) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr
func (LexedStatements) HasStatements ¶
func (s LexedStatements) HasStatements() bool
func (LexedStatements) IsValid ¶
func (s LexedStatements) IsValid() bool
func (LexedStatements) Message ¶
func (s LexedStatements) Message() *capnp.Message
func (LexedStatements) NewStatements ¶
func (s LexedStatements) NewStatements(n int32) (Statement_List, error)
NewStatements sets the statements field to a newly allocated Statement_List, preferring placement in s's segment.
func (LexedStatements) Segment ¶
func (s LexedStatements) Segment() *capnp.Segment
func (LexedStatements) SetStatements ¶
func (s LexedStatements) SetStatements(v Statement_List) error
func (LexedStatements) Statements ¶
func (s LexedStatements) Statements() (Statement_List, error)
func (LexedStatements) String ¶
func (s LexedStatements) String() string
func (LexedStatements) ToPtr ¶
func (s LexedStatements) ToPtr() capnp.Ptr
type LexedStatements_Future ¶
LexedStatements_Future is a wrapper for a LexedStatements promised by a client call.
func (LexedStatements_Future) Struct ¶
func (f LexedStatements_Future) Struct() (LexedStatements, error)
type LexedStatements_List ¶
type LexedStatements_List = capnp.StructList[LexedStatements]
LexedStatements_List is a list of LexedStatements.
func NewLexedStatements_List ¶
func NewLexedStatements_List(s *capnp.Segment, sz int32) (LexedStatements_List, error)
NewLexedStatements creates a new list of LexedStatements.
type LexedTokens ¶
func NewLexedTokens ¶
func NewLexedTokens(s *capnp.Segment) (LexedTokens, error)
func NewRootLexedTokens ¶
func NewRootLexedTokens(s *capnp.Segment) (LexedTokens, error)
func ReadRootLexedTokens ¶
func ReadRootLexedTokens(msg *capnp.Message) (LexedTokens, error)
func (LexedTokens) DecodeFromPtr ¶
func (LexedTokens) DecodeFromPtr(p capnp.Ptr) LexedTokens
func (LexedTokens) EncodeAsPtr ¶
func (s LexedTokens) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr
func (LexedTokens) HasTokens ¶
func (s LexedTokens) HasTokens() bool
func (LexedTokens) IsValid ¶
func (s LexedTokens) IsValid() bool
func (LexedTokens) Message ¶
func (s LexedTokens) Message() *capnp.Message
func (LexedTokens) NewTokens ¶
func (s LexedTokens) NewTokens(n int32) (Token_List, error)
NewTokens sets the tokens field to a newly allocated Token_List, preferring placement in s's segment.
func (LexedTokens) Segment ¶
func (s LexedTokens) Segment() *capnp.Segment
func (LexedTokens) SetTokens ¶
func (s LexedTokens) SetTokens(v Token_List) error
func (LexedTokens) String ¶
func (s LexedTokens) String() string
func (LexedTokens) ToPtr ¶
func (s LexedTokens) ToPtr() capnp.Ptr
func (LexedTokens) Tokens ¶
func (s LexedTokens) Tokens() (Token_List, error)
type LexedTokens_Future ¶
LexedTokens_Future is a wrapper for a LexedTokens promised by a client call.
func (LexedTokens_Future) Struct ¶
func (f LexedTokens_Future) Struct() (LexedTokens, error)
type LexedTokens_List ¶
type LexedTokens_List = capnp.StructList[LexedTokens]
LexedTokens_List is a list of LexedTokens.
func NewLexedTokens_List ¶
func NewLexedTokens_List(s *capnp.Segment, sz int32) (LexedTokens_List, error)
NewLexedTokens creates a new list of LexedTokens.
type Statement ¶
func (Statement) Block ¶
func (s Statement) Block() (Statement_List, error)
func (Statement) DocComment ¶
func (Statement) DocCommentBytes ¶
func (Statement) HasDocComment ¶
func (Statement) NewBlock ¶
func (s Statement) NewBlock(n int32) (Statement_List, error)
NewBlock sets the block field to a newly allocated Statement_List, preferring placement in s's segment.
func (Statement) NewTokens ¶
func (s Statement) NewTokens(n int32) (Token_List, error)
NewTokens sets the tokens field to a newly allocated Token_List, preferring placement in s's segment.
func (Statement) SetBlock ¶
func (s Statement) SetBlock(v Statement_List) error
func (Statement) SetDocComment ¶
func (Statement) SetEndByte ¶
func (Statement) SetStartByte ¶
func (Statement) SetTokens ¶
func (s Statement) SetTokens(v Token_List) error
func (Statement) Tokens ¶
func (s Statement) Tokens() (Token_List, error)
func (Statement) Which ¶
func (s Statement) Which() Statement_Which
type Statement_Future ¶
Statement_Future is a wrapper for a Statement promised by a client call.
func (Statement_Future) Struct ¶
func (f Statement_Future) Struct() (Statement, error)
type Statement_List ¶
type Statement_List = capnp.StructList[Statement]
Statement_List is a list of Statement.
func NewStatement_List ¶
func NewStatement_List(s *capnp.Segment, sz int32) (Statement_List, error)
NewStatement creates a new list of Statement.
type Statement_Which ¶
type Statement_Which uint16
const ( Statement_Which_line Statement_Which = 0 Statement_Which_block Statement_Which = 1 )
func (Statement_Which) String ¶
func (w Statement_Which) String() string
type Token ¶
func (Token) BinaryLiteral ¶
func (Token) BracketedList ¶
func (s Token) BracketedList() (capnp.PointerList, error)
func (Token) FloatLiteral ¶
func (Token) HasBinaryLiteral ¶
func (Token) HasBracketedList ¶
func (Token) HasIdentifier ¶
func (Token) HasOperator ¶
func (Token) HasParenthesizedList ¶
func (Token) HasStringLiteral ¶
func (Token) Identifier ¶
func (Token) IdentifierBytes ¶
func (Token) IntegerLiteral ¶
func (Token) NewBracketedList ¶
func (s Token) NewBracketedList(n int32) (capnp.PointerList, error)
NewBracketedList sets the bracketedList field to a newly allocated capnp.PointerList, preferring placement in s's segment.
func (Token) NewParenthesizedList ¶
func (s Token) NewParenthesizedList(n int32) (capnp.PointerList, error)
NewParenthesizedList sets the parenthesizedList field to a newly allocated capnp.PointerList, preferring placement in s's segment.
func (Token) OperatorBytes ¶
func (Token) ParenthesizedList ¶
func (s Token) ParenthesizedList() (capnp.PointerList, error)
func (Token) SetBinaryLiteral ¶
func (Token) SetBracketedList ¶
func (s Token) SetBracketedList(v capnp.PointerList) error
func (Token) SetEndByte ¶
func (Token) SetFloatLiteral ¶
func (Token) SetIdentifier ¶
func (Token) SetIntegerLiteral ¶
func (Token) SetOperator ¶
func (Token) SetParenthesizedList ¶
func (s Token) SetParenthesizedList(v capnp.PointerList) error
func (Token) SetStartByte ¶
func (Token) SetStringLiteral ¶
func (Token) StringLiteral ¶
func (Token) StringLiteralBytes ¶
func (Token) Which ¶
func (s Token) Which() Token_Which
type Token_Future ¶
Token_Future is a wrapper for a Token promised by a client call.
func (Token_Future) Struct ¶
func (f Token_Future) Struct() (Token, error)
type Token_List ¶
type Token_List = capnp.StructList[Token]
Token_List is a list of Token.
func NewToken_List ¶
func NewToken_List(s *capnp.Segment, sz int32) (Token_List, error)
NewToken creates a new list of Token.
type Token_Which ¶
type Token_Which uint16
const ( Token_Which_identifier Token_Which = 0 Token_Which_stringLiteral Token_Which = 1 Token_Which_binaryLiteral Token_Which = 7 Token_Which_integerLiteral Token_Which = 2 Token_Which_floatLiteral Token_Which = 3 Token_Which_operator Token_Which = 4 Token_Which_parenthesizedList Token_Which = 5 Token_Which_bracketedList Token_Which = 6 )
func (Token_Which) String ¶
func (w Token_Which) String() string